@@ -30,6 +30,9 @@
 namespace Glom
 {
 
+class LayoutItem_Field;
+class LayoutGroup;
+
 //TODO: This should probably be renamed to Formatting, because it is used for static text items too.
 class FieldFormatting : public UsesRelationship //The UsesRelationship base has the relationship for the choices.
 {
@@ -45,6 +48,7 @@ public:
   bool get_has_choices() const;
 
   bool get_has_related_choices() const;
+  bool get_has_related_choices(bool& show_all, bool& with_second) const;
   void set_has_related_choices(bool val = true);
 
   bool get_has_custom_choices() const;
@@ -54,11 +58,26 @@ public:
   virtual type_list_values get_choices_custom() const;
   virtual void set_choices_custom(const type_list_values& choices);
 
-  bool get_choices_restricted() const;
-  void set_choices_restricted(bool val = true);
+  /** Discover whether the entered data should only be one of the available
+   * choices.
+   * @param [out] as_radio_buttons: Whether the choices should be displayed as
+   * radio buttons instead of a combo box.
+   */
+  bool get_choices_restricted(bool& as_radio_buttons) const;
+
+  /** See get_choices_restricted().
+   */
+  void set_choices_restricted(bool val = true, bool as_radio_buttons = false);
+
+  void get_choices_related(sharedptr<const Relationship>& relationship_name, sharedptr<LayoutItem_Field>& field, sharedptr<LayoutGroup>& extra_layout, bool& show_all);
+  void get_choices_related(sharedptr<const Relationship>& relationship_name, sharedptr<const LayoutItem_Field>& field, sharedptr<const LayoutGroup>& extra_layout, bool& show_all) const;
+  void set_choices_related(const sharedptr<const Relationship>& relationship_name, const sharedptr<LayoutItem_Field>& field, const sharedptr<LayoutGroup>& extra_layout, bool show_all);
+
+  //Just for convenience:
+  sharedptr<const Relationship> get_choices_related_relationship(bool& show_all) const;
+
+
 
-  void get_choices(sharedptr<Relationship>& relationship_name, Glib::ustring& field, Glib::ustring& field_second) const;
-  void set_choices(const sharedptr<Relationship>& relationship_name, const Glib::ustring& field, const Glib::ustring& field_second);
 
   /** Get whether the text should be displayed with multiple lines in the
    * details view. Text is displayed with a single line in the list view.
@@ -128,20 +147,19 @@ public:
   {
     HORIZONTAL_ALIGNMENT_AUTO, //For instance, RIGHT for numeric fields.
     HORIZONTAL_ALIGNMENT_LEFT,
-    HORIZONTAL_ALIGNMENT_RIGHT,
+    HORIZONTAL_ALIGNMENT_RIGHT
   };
 
   void set_horizontal_alignment(HorizontalAlignment alignment);
   HorizontalAlignment get_horizontal_alignment() const;
 
-  void change_field_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
-
   NumericFormat m_numeric_format; //Only used for numeric fields.
 
 private:
 
   type_list_values m_choices_custom_list; //A drop-down list of possible values for the field.
   bool m_choices_restricted;
+  bool m_choices_restricted_as_radio_buttons;
   bool m_choices_custom, m_choices_related;
 
   bool m_text_format_multiline;
@@ -151,12 +169,11 @@ private:
   Glib::ustring m_text_color_foreground, m_text_color_background;
   HorizontalAlignment m_horizontal_alignment;
 
-  Glib::ustring m_choices_related_field, m_choices_related_field_second;
+  sharedptr<LayoutItem_Field> m_choices_related_field;
+  sharedptr<LayoutGroup> m_choices_extra_layout_group;
+  bool m_choices_related_show_all;
 };
 
 } //namespace Glom
 
 #endif //GLOM_DATASTRUCTURE_FIELDFORMATTING_H
-
-
-
