@@ -18,8 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef DIALOG_FIELDCALCULATION_H
-#define DIALOG_FIELDCALCULATION_H
+#ifndef GLOM_MODE_DESIGN_DIALOG_FIELDCALCULATION_H
+#define GLOM_MODE_DESIGN_DIALOG_FIELDCALCULATION_H
 
 #include <gtkmm.h>
 #include <gtkmm/builder.h>
@@ -49,7 +49,7 @@ private:
   void on_button_test();
   bool check_for_return_statement(const Glib::ustring& calculation);
 
-  gtksourceview::SourceView* m_text_view;
+  Gsv::SourceView* m_text_view;
   Gtk::Button* m_button_test;
   Gtk::Label* m_label_triggered_by;
 
@@ -59,4 +59,4 @@ private:
 
 } //namespace Glom
 
-#endif //DIALOG_FIELDCALCULATION_H
+#endif // GLOM_MODE_DESIGN_DIALOG_FIELDCALCULATION_H
