@@ -18,8 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef DIALOG_FIELDDEFINITION_H
-#define DIALOG_FIELDDEFINITION_H
+#ifndef GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
+#define GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
 
 #include <gtkmm.h>
 #include "../../utility_widgets/combo_textglade.h"
@@ -84,7 +84,7 @@ private:
 
   Gtk::RadioButton* m_pRadio_Calculate;
   Gtk::Alignment* m_pAlignment_Calculate;
-  gtksourceview::SourceView* m_pTextView_Calculation;
+  Gsv::SourceView* m_pTextView_Calculation;
   Gtk::Button* m_pButton_EditCalculation;
 
   Gtk::Entry* m_pEntry_Title;
@@ -100,4 +100,4 @@ private:
 
 } //namespace Glom
 
-#endif //DIALOG_FIELDDEFINITION_H
+#endif // GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
